package net.cephas.blog;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Calendar;
import java.util.Date;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import org.apache.xmlrpc.XmlRpcClient;
import org.apache.xmlrpc.XmlRpcException;

import del.icio.us.Delicious;
import del.icio.us.beans.Post;

/**
 * @author JOHNSONAA
 *
 */
public class DeliciousPoster {
	public static void main(String[] args) {
		
		String properties;
		if (args.length < 1) {
			printUsage();
		} else {
			properties = args[0];
			DeliciousPosterConfig config = null; 
			try {
				config = DeliciousPosterConfig.parseProperties(properties);
			} catch (IOException e) {
				System.out.println("The properties file you specified could not be found.");
				System.exit(1);
			}
			
			int previousDays = -1;
			if (args.length > 1) {
				previousDays = Integer.parseInt(args[1]);
			}
			
			
			Calendar calendar = Calendar.getInstance();
			calendar.add(Calendar.DAY_OF_MONTH, previousDays);
			Date yesterday = calendar.getTime();
			List entries = getEntries(config, yesterday);
			
			if (entries.size() > 0) {
				StringBuffer sb = new StringBuffer();
				sb.append("<ul>");
				for (Iterator i=entries.iterator(); i.hasNext();) {
					Post post = (Post)i.next();
					sb.append("<li>");
					sb.append("<a href='" + post.getHref() + "'>");
					sb.append(post.getDescription());
					sb.append("</a><br />");
					sb.append("<em>Posted: " + post.getTime());
					sb.append("(categories: ");
					String[] categories = post.getTag().split(" ");
					for (int j=0; j<categories.length; j++) {
						sb.append("<a href='http://del.icio.us/ajohnson1200/" + 
							categories[j] + "'>" + categories[j] + " ");
					}
					sb.append(")</em></li>");
				}
				sb.append("</ul>");
				
				String title = "Links: " + calendar.get(Calendar.DATE) + 
					"-" + (calendar.get(Calendar.MONTH) + 1) + 
					"-" + calendar.get(Calendar.YEAR);
				
				try {
					postToMT(config, title, sb.toString());
				} catch (MalformedURLException e1) {
					System.out.println("The MT URL you used isn't valid.");
					e1.printStackTrace();
				} catch (IOException e1) {
					System.out.println("There was a problem contacting your MT server.");
				} catch (XmlRpcException e1) {
					System.out.println("There was a problem contacting your XML-RPC service.");
				}
				
			}
			
			
		}
		
		 
	
	}
	
	public static List getEntries(DeliciousPosterConfig config, Date date) {
		Delicious yummy = new Delicious(config.getDeusername(), config.getDepassword());
		return yummy.getPostsForDate(null, date);
	}
	
	
	public static void postToMT(DeliciousPosterConfig config, String title, String body)
		throws MalformedURLException, IOException, XmlRpcException {
		
		XmlRpcClient xmlrpc = new XmlRpcClient(config.getMturl());
		Hashtable structContents=new Hashtable();
		structContents.put("title",title);
		structContents.put("description",body);
		Boolean publish = new Boolean(true);
	
		Vector params = new Vector();
		params.add(config.getMtblogid());
		params.add(config.getMtusername());
		params.add(config.getMtpassword());
		params.add(structContents);
		params.add(publish); 
		Object message = xmlrpc.execute("metaWeblog.newPost",params);
		System.out.println(message.toString());
	}
	
	public static void printUsage() {
		String linesep = "-------------------------------------";
		System.out.println(
				"\n\n" +
				"Configuring DeliciousPoster:\n" + linesep + "\n" +
				"Edit the included config.properties file so that it includes " + 
				"your Movable Type username / password / URL and Blog ID and " + 
				"your del.icio.us username and password." + "\n\n" +
				"Using DeliciousPoster:\n" + linesep + "\n" +
				"Windows:\n" + 
				"java -cp commons-codec-1.3.jar;commons-httpclient-3.0-rc2.jar;" +
				"commons-logging-1.0.4.jar;delicious-1.6.jar;xmlrpc-1.2-b1.jar;." + 
				"net.cephas.blog.DeliciousPoster $x $y" +
				"\n\n" + 
				"Linux:\n" + 
				"java -cp commons-codec-1.3.jar:commons-httpclient-3.0-rc2.jar:" +
				"commons-logging-1.0.4.jar:delicious-1.6.jar:xmlrpc-1.2-b1.jar:." + 
				"net.cephas.blog.DeliciousPoster $x $y" +
				"\n\n" +
				"where $x is the name of your configuration document (the sample " +
				"provided is called config.properties) and $y is a number less than " +
				"or equal to zero that indicates how many days previous you'd like to " +
				"go to retrieve your del.icio.us feed (ie: -1 is yesterday, -7 is last " +
				"week, etc)."
				);
		
	}

	
	

	
}
